@@ -137,7 +137,7 @@ class ZIDS_Workflow():
         template.placement = cluster_config
         return template
 
-    def create_ordered_job(self, stage_dir: str, spark_properties, python_files) -> OrderedJob:
+    def create_ordered_job(self, stage_dir: str, spark_properties, python_files, archive_files) -> OrderedJob:
         """! ZIDS_Workflow create_ordered_job.
         Create an ordered job from a stage directory
 
@@ -145,7 +145,8 @@ class ZIDS_Workflow():
                 stage_dir: Stage directory, should hold the main.py file and configuration
                            example: batch_files/stages/stage_write_page_list_to_big_query
                 spark_properties: A list, containing different spark properties
-                python_files: A list of compressed files which hold the project code
+                python_files: A list of files which hold the project code (Can be archived)
+                archive_files: A list of compressed files that the stage requires
             Returns:
                 An ordered job
         """
@@ -156,8 +157,10 @@ class ZIDS_Workflow():
         created_stage = OrderedJob()
         pyJob = PySparkJob()
         pyJob.main_python_file_uri = f'{self.bucket_path}/{stage_dir}/main.py'
-        pyJob.archive_uris = [f'{self.bucket_path}/dist/{file_name}' for file_name in python_files]
-        pyJob.python_file_uris = [f'{self.bucket_path}/dist/{file_name}' for file_name in python_files]
+        pyJob.archive_uris = [f'{self.bucket_path}/dist/{file_name}' if file_name.find('gs:') == -1
+                              else file_name for file_name in archive_files]
+        pyJob.python_file_uris = [f'{self.bucket_path}/dist/{file_name}' if file_name.find('gs:') == -1
+                                  else file_name for file_name in python_files]
         pyJob.properties = spark_properties
         pyJob.args = self.default_args + []
         pyJob.jar_file_uris = self.default_jars + []
