@@ -3,34 +3,50 @@ import json
 from typing import Dict, List
 from dsframework.base.common.functions import flatten
 
+##
+# @file
+# @brief ZIDS_Tester base class for general_tester.py
 
 class ZIDS_Tester:
-
+    """ZIDS_Tester class base class for general_tester.py, contains methods to format data to Inputs, Outputs and dsp,
+        requirements.
+    """
     def __init__(self):
+        """! ZIDS_Tester initializer.
+
+        Initializes local variables.
+        """
         self.truth_dataset_id = -1
         self.model_type_id = -1
         self.data_keys = []
+        ## Prediction field name
         self.pred_name = ""
+        ## Ground truth fields name - implemented in derived class.
         self.target_name = ""
 
     def save_meta_data(self, input_req):
-        """
-        Save input request meta data.
-        Parameters:
+        """! Save input request metadata, truth_dataset_id and model_type_id.
+
+        Args:
             input_req: An object of type TestInputRequest
         """
+
+        ## Truth dataset ID
         self.truth_dataset_id = input_req.truth_dataset_id
+        ## Model type ID
         self.model_type_id = input_req.model_type_id
 
     def test_batch(self, test_request):
+        """Implemented in derived class generatedClassGeneralTester in file general_tester.py"""
         raise NotImplementedError
 
     def convert_input_to_dataframe(self, data_rows):
-        """
-        Convert from a list of TestInputRow to a dataframe.
-        Also apply Model-Specific conversion.
+        """! Convert from a list of TestInputRow to a dataframe.
+        - Used in general_tester.py test_batch()
+        - Also apply Model-Specific conversion.
 
-        Parameters:
+
+        Args:
             data_rows: A list of objects, List[TestInputRow]
         Returns:
             Pandas dataframe that contains all the relevant information
@@ -40,12 +56,13 @@ class ZIDS_Tester:
         return df
 
     def create_model_request(self, batch_input_rows):
+        """Implemented in derived class generatedClassGeneralTester in file general_tester.py"""
         raise NotImplementedError
 
     def run_model_on_data_rows(self, row_dataframe: pd.DataFrame) -> pd.DataFrame:
-        """
-        Run model on all data rows. Create a format the the model can work with, and run the pipeline.
-        Parameters:
+        """! Runs model on all data rows. Create a format, the model can work with and runs the pipeline.
+
+        Args:
             row_dataframe: Input dataframe, containing all data rows.
         Returns:
             Extended dataframe which contains the output of the model
@@ -67,18 +84,18 @@ class ZIDS_Tester:
         return row_dataframe
 
     def adapt_to_dsp_format(self, df_row):
-        """
-        Adapt for DSP format compatibility
+        """! Adapt for DSP format compatibility
         'data' is provided as string since the DSP saves it this way.
-        Please feel free to modify due to your project needs
+        Please feel free to modify due to your project needs.
 
-        Parameters:
+
+        Args:
             df_row: A single row from the processed data frame
         Returns:
             df_row: The flattened data frame, with all the fields previously compressed in the 'data' field
         """
 
-        # Extract keys for later use
+        ##  Extract keys for later use
         self.data_keys = json.loads(df_row['data']).keys()
 
         # Restructure as a data frame line
@@ -87,23 +104,38 @@ class ZIDS_Tester:
         return df_row
 
     def create_predicted_records_dataframe(self, predicted_records):
-        # create a dataframe formatted as input for evaluation
+        """! Create a dataframe formatted as input for evaluation
+
+        Args:
+            predicted_records: Results from pipeline
+        Returns:
+            df_predicted: DataFrame
+        """
+
         df_predicted = pd.DataFrame(predicted_records)
         df_predicted = df_predicted.rename(columns={self.pred_name: 'pred_model'})
         return df_predicted
 
     @staticmethod
     def create_empty_predictions(row_dataframe):
-        """
-        Create empty predictions in case where the model returns an error and we wish to keep evaluating
+        """! Create empty predictions in case the model returns an error, and we wish to keep evaluating.
+        Not implemented yet.
+
+
+        Args:
+            row_dataframe: Input dataframe, containing all data rows.
+        Raises:
+            NotImplementedError
         """
         raise NotImplementedError
 
     def format_evaluation_output(self, row_dataframe) -> List[Dict]:
-        """
-        Make the results fit with the expected DSP data format
-        :param row_dataframe:
-        :return:
+        """! Format the results with the expected DSP data format.
+
+        Args:
+            row_dataframe: Results from evaluation
+        Returns:
+            List[Dict]: In dsp format
         """
 
         row_dataframe = row_dataframe.rename(columns={'pred': 'target', 'pred_model': 'pred'})
@@ -128,11 +160,13 @@ class ZIDS_Tester:
 
     @staticmethod
     def format_response_row_for_dsp_upload(output, test_request):
-        """
-        Adapt response format to the DSP requirements
-        :param output:
-        :param test_request:
-        :return:
+        """! Format response rows (including results) to follow DSP requirements.
+
+        Args:
+            output: model_evaluation_results
+            test_request: Include ids required for response - truth_dataset_id, model_type_id -
+        Returns:
+            Doesn't return, make changes by reference to input argument 'output'.
         """
         row_extra_data = {
             "truth_dataset_id": test_request.truth_dataset_id,
@@ -155,12 +189,16 @@ class ZIDS_Tester:
 
     @staticmethod
     def get_f1_precision_recall(var_name, df):
-        """
-        Calculate from detailed output report the f1, precision and recall scores per attribute.
-        @param var_name: variable name to calculate the scores for.
-        @param df: detailed results dataframe with per attribute confusion matrix as outputted by tester.
-        @return: f1, precision and recall scores.
+        """! Calculate from detailed output report the f1, precision and recall scores per attribute.
+
         This function should be overridden if other form of calculation is needed
+
+        Args:
+            var_name: variable name to calculate the scores for.
+            df: detailed results dataframe with per attribute confusion matrix as outputted by tester.
+        Returns:
+            f1, precision and recall scores.
+
         """
         tp = df[var_name + '_tp']
         fp = df[var_name + '_fp']
