@@ -6,6 +6,9 @@ import base64
 import json
 from datetime import datetime, timedelta
 
+##
+# @file
+# @brief token_generator -  Generate token from a given account, host and target_audience (which is stored in advance)
 
 class tokenGenerator():
 	# account example - original_project_name@dozi-stg-ds-apps-1.iam.gserviceaccount.com
@@ -30,6 +33,15 @@ class tokenGenerator():
 	}
 
 	def generateToken(self, type):
+		"""! Generate token by the help of the type, and store it in the self.tokens[type]
+		@verbatim
+		Args:
+			type: STG_Conf or PRD_Conf
+		Returns:
+			tokens[type] : tokens associated with the relevant credentials
+		@endverbatim
+		"""
+
 		if self.isExpired(type):
 			self.resetToken(type)
 		if not type or not self.conf[type]:
@@ -51,11 +63,23 @@ class tokenGenerator():
 		return self.tokens[type]
 
 	def authorize(self):
-		# return google.auth.default(
-		# 	scopes=['https://www.googleapis.com/auth/cloud-platform'])
+		"""! Authorize return if we got credentials on google.
+		@verbatim
+		Returns:
+			credentials : return google.auth.default(scopes=['https://www.googleapis.com/auth/cloud-platform'])
+		@endverbatim
+		"""
 		return GoogleCredentials.get_application_default()
 
 	def getToken(self, credentials, conf):
+		"""! getToken Method, using credentials and request for token.
+
+		Args:
+			credentials : ServiceAccount credentials
+			conf (not in use): dictionary including relevant fields like: account,project,target_audience,iap.
+		Returns:
+			token : jwtToken
+		"""
 		client_id = credentials.client_id
 		client_secret = credentials.client_secret
 		aud = credentials.token_uri
@@ -76,6 +100,20 @@ class tokenGenerator():
 		return response['signedJwt']
 
 	def buildIdToken(self, client, jwtToken, conf):
+		"""! BuildIdToken method, send the user to their OpenID Provider with an authentication request and get the id_token.
+		In General:
+		The id_token value contains the information about the user's authentication.
+		The ID token resembles the concept of an identity card, in a standard JWT format, signed by the OpenID Provider (OIDP).
+
+		@verbatim
+		Args:
+			client : Not in use
+			jwtToken : Authentication
+			conf : dictionary including relevant fields like: account,project,target_audience,iap.
+		Returns:
+			token : id_token
+		@endverbatim
+		"""
 		try:
 			data = {
 				"method": 'post',
@@ -98,6 +136,14 @@ class tokenGenerator():
 			print(ex)
 
 	def isExpired(self, type):
+		"""! Is Expired method , tell us whether the token has expired or not.
+		@verbatim
+		Args:
+			type : STG_Conf or PRD_Conf
+		Returns:
+			isExpired : bool
+		@endverbatim
+		"""
 		isExpired = True
 		if self.tokens[type]:
 			decoded = self.parse_id_token(self.tokens[type])
@@ -113,12 +159,17 @@ class tokenGenerator():
 		return isExpired
 
 	def resetToken(self, type):
+		"""! Reset the token
+		@verbatim
+		Args:
+			type : STG_Conf or PRD_Conf
+		@endverbatim
+		"""
 		self.tokens[type] = ''
 
 	@staticmethod
 	def parse_id_token(token: str) -> dict:
-		"""
-		Parse Google OAuth2.0 id_token payload
+		"""! Parse Google OAuth2.0 id_token payload
 		An ID token has the following structure: Base64(JOSE header).Base64(Payload).Base64(Signature)
 		"""
 		parts = token.split(".")
